@@ -6,9 +6,9 @@ class Parser:
 
     scraper = None
 
-    def __init__(self, config: Config, user_dir: str=None, headless: bool=True, disable_javascript: bool=False, window: dict={}, proxy_address: str=None) -> None:
+    def __init__(self, config: Config, user_dir: str=None, headless: bool=True, fullscreen: bool=False, disable_javascript: bool=False, window: dict={}, proxy_address: str=None) -> None:
         self.config = config
-        self.scraper = self.get_scraper(config=config, headless=headless, disable_javascript=disable_javascript, window=window, user_dir=user_dir, proxy_address=proxy_address)
+        self.scraper = self.get_scraper(config=config, headless=headless, fullscreen=fullscreen, disable_javascript=disable_javascript, window=window, user_dir=user_dir, proxy_address=proxy_address)
 
     # region methods
     def click(self, path: str, element: any=None, timeout: int=0) -> any:
