@@ -13,13 +13,13 @@ class Integration:
 
 class WebScraper:
 
-    class Functions(Enum):
+    class Functions:
         SUBSTRING = 'substring'
         EXPLODE = 'explode'
         REPLACE = 'join'
         JOIN = 'join'
 
-    class Types(Enum):
+    class Types:
         PERCENTAGE = 'PERCENTAGE'
         BOOL = 'BOOL'
         MONEY = 'MONEY'
@@ -33,7 +33,7 @@ class WebScraper:
         JSON = 'JSON'
         STRING = 'STRING'
 
-    class Properties(Enum):
+    class Properties:
         TEXT = 'text()'
         HTML = 'html()'
 
